@@ -74,12 +74,18 @@ pub struct Props {
     #[prop_or_default]
     pub disabled: bool,
 
+    #[prop_or_default]
+    pub block: bool,
+
     #[prop_or_default]
     pub aria_label: Option<String>,
 
     #[prop_or("button".into())]
     pub r#type: String,
 
+    #[prop_or_default]
+    pub role: Option<String>,
+
     #[prop_or_default]
     pub expanded: bool,
 
@@ -143,6 +149,9 @@ impl Component for Button {
         if self.props.expanded {
             classes.push("pf-m-expanded");
         }
+        if self.props.block {
+            classes.push("pf-m-block");
+        }
 
         return html! {
             <button
@@ -152,7 +161,9 @@ impl Component for Button {
                 style=self.props.style.as_ref().cloned().unwrap_or_default()
                 disabled=self.props.disabled
                 type=self.props.r#type
-                onclick=self.link.callback(Msg::Clicked)>
+                onclick=self.link.callback(Msg::Clicked)
+                role=self.props.role.clone().unwrap_or_default()
+            >
 
                 { self.label() }
                 { for self.props.children.iter() }
